# This file is part of fedmsg.
# Copyright (C) 2013 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for tagger messages """

import unittest

from fedmsg.tests.test_meta import Base

from common import add_doc


class TestTaggerVoteAuthenticated(Base):
    """ `Fedora Tagger <https://apps.fedoraproject.org/tagger>`_
    publishes messages like this one when a user votes on a tag.
    Users may upvote or downvote a tag and they may do so either
    anonymously or authenticated.  Here's an example of an
    authenticated downvote:
    """

    expected_title = "fedoratagger.tag.update"
    expected_subti = 'ralph downvoted "stupid" on mattd'
    expected_link = 'https://apps.fedoraproject.org/tagger/mattd'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/2f933f4364baaabd2d3ab8f0664faef2'
        '?s=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages'
        '%2Ffedora_infinity_64x64.png')
    expected_usernames = set(['ralph'])
    expected_packages = set(['mattd'])
    expected_objects = set(['packages/mattd', 'labels/stupid'])
    msg = {
        "i": 3,
        "msg": {
            "vote": {
                "tag": {
                    "votes": 1,
                    "like": 0,
                    "package": "mattd",
                    "tag": "stupid",
                    "dislike": 1,
                    "total": -1
                },
                "like": False,
                "user": {
                    "username": "ralph",
                    "votes": 4,
                    "rank": -1,
                    "anonymous": False
                }
            },
            "tag": {
                "votes": 1,
                "like": 0,
                "package": "mattd",
                "tag": "stupid",
                "dislike": 1,
                "total": -1
            },
            "user": {
                "username": "ralph",
                "votes": 4,
                "rank": -1,
                "anonymous": False
            }
        },
        "topic": "org.fedoraproject.dev.fedoratagger.tag.update",
        "username": "threebean",
        "timestamp": 1365444503.627384
    }


class TestTaggerRatingUpdateAnonymous(Base):
    """ `Fedora Tagger <https://apps.fedoraproject.org/tagger>`_
    doesn't just do tagging of packages, in new versions it also
    allows users to rate packages.  It publishes messages like this
    one when an anonymous user updates their rating of a package.
    """
    expected_title = "fedoratagger.rating.update"
    expected_subti = 'An anonymous user gave nethack a rating of 15'
    expected_link = 'https://apps.fedoraproject.org/tagger/nethack'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_usernames = set([])
    expected_packages = set(['nethack'])
    expected_objects = set(['packages/nethack'])

    msg = {
        "i": 1,
        "msg": {
            "rating": {
                "rating": 15,
                "user": {
                    "username": "anonymous",
                    "votes": 0,
                    "anonymous": True,
                    "rank": -1
                },
                "package": {
                    "rating": 15.0,
                    "tags": [
                        {
                            "votes": 1,
                            "like": 1,
                            "package": "nethack",
                            "tag": "awesome",
                            "dislike": 0,
                            "total": 1
                        }
                    ],
                    "name": "nethack",
                    "icon": "https://apps.fedoraproject.org/packages/images/"
                    "icons/package_128x128.png",
                    "summary": ""
                }
            }
        },
        "topic": "org.fedoraproject.dev.fedoratagger.rating.update",
        "username": "threebean",
        "timestamp": 1365514895.61764
    }


class TestTaggerCreate(Base):
    """ `Fedora Tagger <https://apps.fedoraproject.org/tagger>`_
    publishes messages like this one when a user **creates** a new tag.
    """
    expected_title = "fedoratagger.tag.create"
    expected_subti = 'ralph added tag "awesome" to mattd'
    expected_link = 'https://apps.fedoraproject.org/tagger/mattd'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/2f933f4364baaabd2d3ab8f0664faef2'
        '?s=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages'
        '%2Ffedora_infinity_64x64.png')
    expected_usernames = set(['ralph'])
    expected_packages = set(['mattd'])
    expected_objects = set(['packages/mattd', 'labels/awesome'])
    msg = {
        "i": 2,
        "msg": {
            "vote": {
                "tag": {
                    "votes": 1,
                    "like": 1,
                    "package": "mattd",
                    "tag": "awesome",
                    "dislike": 0,
                    "total": 1
                },
                "like": True,
                "user": {
                    "username": "ralph",
                    "votes": 4,
                    "rank": -1,
                    "anonymous": False,
                }
            },
            "tag": {
                "votes": 1,
                "like": 1,
                "package": "mattd",
                "tag": "awesome",
                "dislike": 0,
                "total": 1
            },
            "user": {
                "username": "ralph",
                "votes": 4,
                "rank": -1,
                "anonymous": False,
            }
        },
        "topic": "org.fedoraproject.dev.fedoratagger.tag.create",
        "username": "threebean",
        "timestamp": 1365444411.924043
    }


class TestTaggerVoteAnonymousLegacy(Base):
    """ Support old legacy tagger messages. """
    expected_title = "fedoratagger.tag.update"
    expected_subti = 'anonymous upvoted "unittest" on perl-Test-Fatal'
    expected_link = 'https://apps.fedoraproject.org/tagger/perl-Test-Fatal'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_usernames = set([])
    expected_packages = set(['perl-Test-Fatal'])
    expected_objects = set(['packages/perl-Test-Fatal', 'labels/unittest'])

    msg = {
        "i": 1,
        "timestamp": 1345220838.2775879,
        "topic": "org.fedoraproject.stg.fedoratagger.tag.update",
        "msg": {
            "vote": {
                "tag": {
                    "votes": 2,
                    "like": 2,
                    "package": {
                        "perl-Test-Fatal": [
                            {
                                "dislike": 0,
                                "total": 1,
                                "tag": "perl",
                                "votes": 1,
                                "like": 1
                            },
                            {
                                "dislike": 0,
                                "total": 2,
                                "tag": "unittest",
                                "votes": 2,
                                "like": 2
                            }
                        ]
                    },
                    "label": {
                        "label": "unittest",
                        "tags": [
                            {
                                "dislike": 0,
                                "total": 2,
                                "tag": "unittest",
                                "votes": 2,
                                "like": 2
                            }
                        ]
                    },
                    "tag": "unittest",
                    "dislike": 0,
                    "total": 2
                },
                "like": True,
                "user": {
                    "username": "anonymous",
                    "all_votes": [],
                    "votes": 0,
                    "rank": -1
                }
            }
        }
    }


class TestTaggerCreateLegacy(Base):
    """ Support old TG2 version of tagger messages. """
    expected_title = "fedoratagger.tag.create"
    expected_subti = 'ralph added tag "unittest" to perl-Test-Fatal'
    expected_link = 'https://apps.fedoraproject.org/tagger/perl-Test-Fatal'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/2f933f4364baaabd2d3ab8f0664faef2'
        '?s=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages'
        '%2Ffedora_infinity_64x64.png')
    expected_usernames = set(['ralph'])
    expected_packages = set(['perl-Test-Fatal'])
    expected_objects = set(['packages/perl-Test-Fatal', 'labels/unittest'])

    msg = {
        "i": 1,
        "timestamp": 1345220073.4948981,
        "topic": "org.fedoraproject.stg.fedoratagger.tag.create",
        "msg": {
            "vote": {
                "tag": {
                    "votes": 1,
                    "like": 1,
                    "package": {
                        "perl-Test-Fatal": [
                            {
                                "dislike": 0,
                                "total": 1,
                                "tag": "unittest",
                                "votes": 1,
                                "like": 1
                            },
                            {
                                "dislike": 0,
                                "total": 1,
                                "tag": "perl",
                                "votes": 1,
                                "like": 1
                            }
                        ]
                    },
                    "label": {
                        "label": "unittest",
                        "tags": [
                            {
                                "dislike": 0,
                                "total": 1,
                                "tag": "unittest",
                                "votes": 1,
                                "like": 1
                            }
                        ]
                    },
                    "tag": "unittest",
                    "dislike": 0,
                    "total": 1
                },
                "like": True,
                "user": {
                    "username": "ralph",
                    "votes": 28,
                    "rank": 1
                }
            }
        }
    }


class TestTaggerToggleUsageOn(Base):
    """ `Fedora Tagger <https://apps.fedoraproject.org/tagger>`_
    publishes messages like this one when a user **toggles** their usage status
    for a package.

    Here is an example of ralph declaring that he uses *passwd*.
    """
    expected_title = "fedoratagger.usage.toggle"
    expected_subti = 'ralph declared that they use passwd'
    expected_link = 'https://apps.fedoraproject.org/tagger/passwd'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/2f933f4364baaabd2d3ab8f0664faef2'
        '?s=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages'
        '%2Ffedora_infinity_64x64.png')
    expected_usernames = set(['ralph'])
    expected_packages = set(['passwd'])
    expected_objects = set(['packages/passwd'])
    msg = {
        "username": "apache",
        "i": 1,
        "timestamp": 1391107443,
        "msg_id": "2014-8b4ffffc-4854-4da5-92b1-d266b4e7f52f",
        "topic": "org.fedoraproject.prod.fedoratagger.usage.toggle",
        "msg": {
            "usage": True,
            "user": {
                "username": "ralph",
                "votes": 859,
                "score": 949,
                "anonymous": False,
                "rank": 6
            },
            "package": {
                "rating": -1.0,
                "name": "passwd",
                "tags": [],
                "summary": "An utility for setting or changing passwords",
                "usage": 1,
                "icon": "https://apps.fedoraproject.org/packages/images/"
                "icons/package_128x128.png"
            }
        }
    }


class TestTaggerToggleUsageOff(Base):
    """ `Fedora Tagger <https://apps.fedoraproject.org/tagger>`_
    publishes messages like this one when a user **toggles** their usage status
    for a package.

    Here is an example of ralph declaring that he *no longer* uses *passwd*.
    """
    expected_title = "fedoratagger.usage.toggle"
    expected_subti = 'ralph declared that they no longer use passwd'
    expected_link = 'https://apps.fedoraproject.org/tagger/passwd'
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/2f933f4364baaabd2d3ab8f0664faef2'
        '?s=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages'
        '%2Ffedora_infinity_64x64.png')
    expected_usernames = set(['ralph'])
    expected_packages = set(['passwd'])
    expected_objects = set(['packages/passwd'])
    msg = {
        "username": "apache",
        "i": 1,
        "timestamp": 1391107443,
        "msg_id": "2014-8b4ffffc-4854-4da5-92b1-d266b4e7f52f",
        "topic": "org.fedoraproject.prod.fedoratagger.usage.toggle",
        "msg": {
            "usage": False,
            "user": {
                "username": "ralph",
                "votes": 859,
                "score": 949,
                "anonymous": False,
                "rank": 6
            },
            "package": {
                "rating": -1.0,
                "name": "passwd",
                "tags": [],
                "summary": "An utility for setting or changing passwords",
                "usage": 0,
                "icon": "https://apps.fedoraproject.org/packages/images/"
                "icons/package_128x128.png"
            }
        }
    }


class TestTaggerRankUpdate(Base):
    """ `Fedora Tagger <https://apps.fedoraproject.org/tagger>`_
    publishes messages like this one when a user's rank on the Fedora Tagger
    leaderboard changes.
    """

    expected_title = "fedoratagger.user.rank.update"
    expected_subti = "immanetize's rank changed to 59"
    expected_icon = 'https://apps.fedoraproject.org/img/icons/tagger.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/db397b708688db9b708f54f3909ec0da'
        '?s=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages'
        '%2Ffedora_infinity_64x64.png')
    expected_usernames = set(['immanetize'])
    expected_packages = set()
    expected_objects = set()
    msg = {
        "msg": {
            "user": {
                "anonymous": False,
                "votes": 176,
                "rank": 59,
                "username": "immanetize",
                "score": 275
            }
        },
        "source_name": "datanommer",
        "timestamp": 1396074860.0,
        "topic": "org.fedoraproject.prod.fedoratagger.user.rank.update",
        "source_version": "0.6.1",
        "i": 1,
        "msg_id": "2014-3893d29a-e9a1-43e0-90f0-333feebb766c"
    }


add_doc(locals())



# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for summershum messages """

import unittest

from fedmsg_meta_fedora_infrastructure.tests.base import Base

from common import add_doc


class TestSummershumComplete(Base):
    """ Fedora Infrastructure runs a background service called `summershum
    <https://github.com/fedora-infra/summershum>`_, the role of which is to
    compute and store hashes of every file of every tarball of every package in
    Fedora.  This data is then to later be used in tests and analysis.

    This message type is published by the summershum backend when it has
    completed processing of a new tarball.
    """

    expected_title = "summershum.ingest.complete"
    expected_subti = "summershum ingested " + \
        "gnome-online-accounts-3.11.90.tar.xz" + \
        " for gnome-online-accounts"
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "72175d155a8b28b6a57d2340b9f58592?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_link = 'http://pkgs.fedoraproject.org/lookaside/pkgs/' + \
        'gnome-online-accounts/gnome-online-accounts-3.11.90.tar.xz/' + \
        '7d32a7ed3653fe4c3de1fd3e9d1e1367/' + \
        'gnome-online-accounts-3.11.90.tar.xz'
    expected_packages = set(['gnome-online-accounts'])
    expected_usernames = set(['rhughes'])
    expected_objects = set([
        'digests/gnome-online-accounts/'
        'gnome-online-accounts-3.11.90.tar.xz/'
        '7d32a7ed3653fe4c3de1fd3e9d1e1367',
    ])

    msg = {
        "username": "threebean",
        "i": 14,
        "timestamp": 1392749080,
        "msg_id": "2014-c5565d9f-edbe-4ec3-9d3a-d2005b32a817",
        "topic": "org.fedoraproject.dev.summershum.ingest.complete",
        "msg": {
            "original": {
                "md5sum": "7d32a7ed3653fe4c3de1fd3e9d1e1367",
                "name": "gnome-online-accounts",
                "agent": "rhughes",
                "filename": "gnome-online-accounts-3.11.90.tar.xz"
            }
        }
    }


class TestSummershumStart(Base):
    """ Fedora Infrastructure runs a background service called `summershum
    <https://github.com/fedora-infra/summershum>`_, the role of which is to
    compute and store hashes of every file of every tarball of every package in
    Fedora.  This data is then to later be used in tests and analysis.

    This message type is published by the summershum backend when **begins
    processing** a new tarball.
    """

    expected_title = "summershum.ingest.start"
    expected_subti = "summershum started working on " + \
        "glibc-2.19-58-ga4fb786.tar.gz for glibc"
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "fd81d216a30015c59bf44d5c3b8be1cc?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_link = 'http://pkgs.fedoraproject.org/lookaside/pkgs/' + \
        'glibc/glibc-2.19-58-ga4fb786.tar.gz/' + \
        '5f636f8001d1397fa6e233a1009df6c1/' + \
        'glibc-2.19-58-ga4fb786.tar.gz'
    expected_packages = set(['glibc'])
    expected_usernames = set(['siddhesh'])
    expected_objects = set([
        'digests/glibc/'
        'glibc-2.19-58-ga4fb786.tar.gz/'
        '5f636f8001d1397fa6e233a1009df6c1'
    ])
    msg = {
        "username": "threebean",
        "i": 15,
        "timestamp": 1392749080,
        "msg_id": "2014-53a77b4a-637e-4b98-a84e-90febb65ab80",
        "topic": "org.fedoraproject.dev.summershum.ingest.start",
        "msg": {
            "original": {
                "md5sum": "5f636f8001d1397fa6e233a1009df6c1",
                "name": "glibc",
                "agent": "siddhesh",
                "filename": "glibc-2.19-58-ga4fb786.tar.gz"
            }
        }
    }


class TestSummershumFail(Base):
    """ Fedora Infrastructure runs a background service called `summershum
    <https://github.com/fedora-infra/summershum>`_, the role of which is to
    compute and store hashes of every file of every tarball of every package in
    Fedora.  This data is then to later be used in tests and analysis.

    This message type is published by the summershum backend when it
    **encounters some error** and cannot process a tarball.
    """

    expected_title = "summershum.ingest.fail"
    expected_subti = "yikes!  summershum failed to process " + \
        "glibc-2.19-58-ga4fb786.tar.gz for glibc"
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "fd81d216a30015c59bf44d5c3b8be1cc?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_link = 'http://pkgs.fedoraproject.org/lookaside/pkgs/' + \
        'glibc/glibc-2.19-58-ga4fb786.tar.gz/' + \
        '5f636f8001d1397fa6e233a1009df6c1/' + \
        'glibc-2.19-58-ga4fb786.tar.gz'
    expected_packages = set(['glibc'])
    expected_usernames = set(['siddhesh'])
    expected_objects = set([
        'digests/glibc/'
        'glibc-2.19-58-ga4fb786.tar.gz/'
        '5f636f8001d1397fa6e233a1009df6c1'
    ])
    msg = {
        "username": "threebean",
        "i": 15,
        "timestamp": 1392749080,
        "msg_id": "2014-53a77b4a-637e-4b98-a84e-90febb65ab80",
        "topic": "org.fedoraproject.dev.summershum.ingest.fail",
        "msg": {
            "original": {
                "md5sum": "5f636f8001d1397fa6e233a1009df6c1",
                "name": "glibc",
                "agent": "siddhesh",
                "filename": "glibc-2.19-58-ga4fb786.tar.gz"
            }
        }
    }


add_doc(locals())


if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2013 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
""" Tests for coprs messages """

import unittest

from fedmsg.tests.test_meta import Base

from common import add_doc


class TestCoprsBuildStart(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a new build starts.
    """
    expected_title = "copr.build.start"
    expected_subti = ("fatka started a new build of the mutt-kz copr")
    expected_icon = 'https://apps.fedoraproject.org/img/icons/copr.png'
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/5f0736d6f93d195ac1a4a3c9a90a379d?'
        's=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages%2Ffedora'
        '_infinity_64x64.png')
    expected_packages = set([])
    expected_usernames = set(['fatka'])
    expected_objects = set([
        'coprs/mutt-kz/build.start',
    ])
    expected_link = (
        "https://copr.fedoraproject.org/coprs/fatka/mutt-kz/")
    msg = {
        u'username': u'copr',
        u'i': 1,
        u'timestamp': 1383956077.2320001,
        u'msg_id': u'2013-675e7b1e-9b7f-4d11-be2f-2b3845817d60',
        u'topic': u'org.fedoraproject.prod.copr.build.start',
        u'msg': {
            u'what': u'build start: user:fatka copr:mutt-kz '
            'build:100 ip:172.16.3.3  pid:12010',
            u'ip': u'172.16.3.3',
            u'who': u'worker-2',
            u'pid': 12010,
            u'copr': u'mutt-kz',
            u'build': 100,
            u'user': u'fatka',
        },
    }


class TestCoprsBuildEnd(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a build has completed.
    """
    expected_title = "copr.build.end"
    expected_subti = ("fatka's mutt-kz copr finished a build")
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/5f0736d6f93d195ac1a4a3c9a90a379d?'
        's=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages%2Ffedora'
        '_infinity_64x64.png')
    expected_packages = set([])
    expected_usernames = set(['fatka'])
    expected_objects = set([
        'coprs/mutt-kz/build.end',
    ])
    expected_link = (
        "https://copr.fedoraproject.org/coprs/fatka/mutt-kz/")
    msg = {
        u'username': u'copr',
        u'i': 4,
        u'timestamp': 1383956707.6340001,
        u'msg_id': u'2013-b05a323d-37ee-4396-9635-7b5dfaf5441b',
        u'topic': u'org.fedoraproject.prod.copr.build.end',
        u'msg': {
            u'status': 1,
            u'what': u'build end: user:fatka copr:mutt-kz build:100 '
            'ip:172.16.3.3  pid:12010 status:1',
            u'ip': u'172.16.3.3',
            u'who': u'worker-2',
            u'pid': 12010,
            u'copr': u'mutt-kz',
            u'build': 100,
            u'user': u'fatka',
        },
    }


class TestCoprsChrootStart(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a copr start a new chroot.
    """
    expected_title = "copr.chroot.start"
    expected_subti = (
        "fatka's mutt-kz copr started a new fedora-20-x86_64 chroot")
    expected_secondary_icon = (
        'http://www.gravatar.com/avatar/5f0736d6f93d195ac1a4a3c9a90a379d?'
        's=64&d=http%3A%2F%2Ffedoraproject.org%2Fstatic%2Fimages%2Ffedora'
        '_infinity_64x64.png')
    expected_packages = set([])
    expected_usernames = set(['fatka'])
    expected_objects = set([
        'coprs/mutt-kz/chroot.start/fedora-20-x86_64',
    ])
    expected_link = (
        "https://copr-be.cloud.fedoraproject.org/results/"
        "fatka/mutt-kz/fedora-20-x86_64/")
    msg = {
        u'username': u'copr',
        u'i': 3,
        u'timestamp': 1383956378.4679999,
        u'msg_id': u'2013-833cca09-2dba-42ad-9863-4f6c3c29a30d',
        u'topic': u'org.fedoraproject.prod.copr.chroot.start',
        u'msg': {
            u'what': u'chroot start: chroot:fedora-20-x86_64 user:fatka '
            'copr:mutt-kz build:100 ip:172.16.3.3  pid:12010',
            u'chroot': u'fedora-20-x86_64',
            u'ip': u'172.16.3.3',
            u'who': u'worker-2',
            u'pid': 12010,
            u'copr': u'mutt-kz',
            u'build': 100,
            u'user': u'fatka',
        },
    }


class TestCoprsWorkerCreate(Base):
    """ `Copr <https://fedorahosted.org/copr/>`_ publishes these messages
    when a new worker is spun up.
    """
    expected_title = "copr.worker.create"
    expected_subti = "a new worker was created"
    expected_link = "https://copr.fedoraproject.org"
    expected_packages = set([])
    expected_usernames = set([])
    expected_objects = set([
        'coprs/worker.create',
    ])
    msg = {
        u'username': u'copr',
        u'i': 1,
        u'timestamp': 1383956077.2320001,
        u'msg_id': u'2013-675e7b1e-9b7f-4d11-be2f-2b3845817d60',
        u'topic': u'org.fedoraproject.prod.copr.worker.create',
        u'msg': {
            u'what': u'creating worker: 172.16.3.3',
            u'ip': u'172.16.3.3',
        },
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()



# This file is part of fedmsg.
# Copyright (C) 2012 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>
#
from fedmsg_meta_fedora_infrastructure import BaseProcessor

from datetime import datetime


class ComposeProcessor(BaseProcessor):
    __name__ = "compose"
    __description__ = "Fedora Release Engineering"
    __link__ = "http://git.fedorahosted.org/cgit/releng"
    __docs__ = "https://fedoraproject.org/wiki/ReleaseEngineering"
    __obj__ = "Composes"

    def subtitle(self, msg, **config):

        try:
            branch = msg['msg']['branch']
        except KeyError:
            # Some old messages in datanommer don't have that branch field,
            # so we have to extract it from the topic.
            branch = msg['topic'].split('.')[-3]
            if branch == 'compose':
                branch = msg['topic'].split('.')[-2]

        arch = msg['msg'].get('arch', '')
        arch = arch and ' (%s)' % arch

        if msg['topic'].endswith('.rsync.start'):
            tmpl = self._(
                "started rsyncing {branch} compose{arch}")
        elif msg['topic'].endswith('.rsync.complete'):
            tmpl = self._(
                "finished rsync of {branch} compose{arch}")
        elif msg['topic'].endswith('.mash.start'):
            tmpl = self._(
                "{branch} compose{arch} started mashing")
        elif msg['topic'].endswith('.mash.complete'):
            tmpl = self._(
                "{branch} compose{arch} finished mashing")
        elif msg['topic'].endswith('.pungify.start'):
            tmpl = self._(
                "started building boot.iso for {branch}{arch}")
        elif msg['topic'].endswith('.pungify.complete'):
            tmpl = self._(
                "finished building boot.iso for {branch}{arch}")
        elif msg['topic'].endswith('.start'):
            tmpl = self._("{branch} compose{arch} started")
        elif msg['topic'].endswith('.complete'):
            tmpl = self._("{branch} compose{arch} completed")
        else:
            raise NotImplementedError("%r" % msg)

        return tmpl.format(branch=branch, arch=arch)

    def link(self, msg, **config):
        arch = msg['msg'].get('arch', '')
        if arch:
            base = "https://dl.fedoraproject.org/pub/" + \
                "fedora-secondary/development"
        else:
            if 'epelbeta' in msg['topic']:
                base = "https://dl.fedoraproject.org/pub/epel/beta/7"
            else:
                base = "https://dl.fedoraproject.org/pub/" + \
                    "fedora/linux/development"

        return base + "/" + msg['msg'].get('branch', '')

    def objects(self, msg, **config):
        branch = msg['topic'].split('.')[4]
        arch = msg['msg'].get('arch', '')
        arch = arch or 'primary'
        return set(["%s/%s" % (branch, arch)])



# This file is part of fedmsg.
# Copyright (C) 2014 Red Hat, Inc.
#
# fedmsg is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# fedmsg is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with fedmsg; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Authors:  Pierre-Yves Chibon <pingou@pingoured.fr>
#
""" Tests for elections/voting messages """

import unittest
import datetime

from fedmsg.tests.test_meta import Base

from common import add_doc


class TestElectionsNew(Base):
    """ These messages are published when someone creates a new elections
    in `elections <https://apps.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.election.new"
    expected_subti = 'pingou created election "test"'
    expected_link = "https://apps.fedoraproject.org/voting/about/test/"
    expected_icon = (None)
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "dc74ba1f40c7d8150dc6291c455d34a6?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/test/election/new'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.election.new",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            "agent": "pingou"
        }
    }


class TestElectionsEdit(Base):
    """ These messages are published when someone edit an elections in
    `elections <https://apps.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.election.edit"
    expected_subti = 'pingou edited election "test"'
    expected_link = "https://apps.fedoraproject.org/voting/about/test/"
    expected_icon = (None)
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "dc74ba1f40c7d8150dc6291c455d34a6?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/test/election/edit'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.election.edit",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            "agent": "pingou"
        }
    }


class TestElectionsCandidateNew(Base):
    """ These messages are published when someone added a candidate to an
    elections in `elections <https://apps.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.candidate.new"
    expected_subti = 'pingou added candidate "Toshio" to election "test"'
    expected_link = "https://apps.fedoraproject.org/voting/about/test/"
    expected_icon = (None)
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "dc74ba1f40c7d8150dc6291c455d34a6?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/test/candidate/new'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.candidate.new",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            'candidate': {
                'url': '',
                'name': 'Toshio'
            },
            "agent": "pingou"
        }
    }


class TestElectionsCandidateEdit(Base):
    """ These messages are published when someone edited a candidate of an
    elections in `elections <https://apps.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.candidate.edit"
    expected_subti = 'pingou edited candidate "Toshio" of election "test"'
    expected_link = "https://apps.fedoraproject.org/voting/about/test/"
    expected_icon = (None)
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "dc74ba1f40c7d8150dc6291c455d34a6?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/test/candidate/edit'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.candidate.edit",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            'candidate': {
                'url': '',
                'name': 'Toshio'
            },
            "agent": "pingou"
        }
    }


class TestElectionsCandidateDelete(Base):
    """ These messages are published when someone add a candidate to an
    elections in `elections <https://apps.fedoraproject.org/voting/>`_.
    """

    expected_title = "fedora_elections.candidate.delete"
    expected_subti = 'pingou deleted candidate "Toshio" of election "test"'
    expected_link = "https://apps.fedoraproject.org/voting/about/test/"
    expected_icon = (None)
    expected_secondary_icon = (
        "http://www.gravatar.com/avatar/"
        "dc74ba1f40c7d8150dc6291c455d34a6?s=64&d=http%3A%2F%2F"
        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
    expected_packages = set([])
    expected_usernames = set(['pingou'])
    expected_objects = set(['test/test/candidate/delete'])
    msg = {
        "username": "pingou",
        "i": 1,
        "timestamp": 1379638157.759283,
        "msg_id": "2013-96f9ca0e-c7c6-43f0-9de7-7a268c7f1cef",
        "topic": "org.fedoraproject.dev.fedora_elections.candidate.delete",
        "msg": {
            "election": {
                "description": "test desc",
                "end_date": 1397080800.0,
                "url": "http: //giuakle.org",
                "embargoed": 1,
                "alias": "test",
                "shortdesc": "test",
                "voting_type": "range",
                "start_date": 1396994400.0
            },
            'candidate': {
                'url': '',
                'name': 'Toshio'
            },
            "agent": "pingou"
        }
    }


add_doc(locals())

if __name__ == '__main__':
    unittest.main()
